---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

:warning: If this is a question about Wn or how to use it, please create a [discussion](https://github.com/goodmami/wn/discussions) instead of an issue.

**To Reproduce**
Please enter a minimal working example of the command or Python code that illustrates the problem. To avoid formatting issues, enter the code in a Markdown code block:

```console
$ python -m wn ...
output...
```

or

```pycon
>>> import wn
>>> ...
output
```

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment**
Please enter the versions of Python and Wn you are using as well as the installed lexicons. You can find these by executing the following commands (adjust your platform-specific Python command as necessary, e.g., `python3` or `py -3`):

```console
python --version
python -m wn --version
python -m wn lexicons
```

**Additional context**
Add any other context about the problem here.
